import { jsx } from 'react/jsx-runtime';
import { useMemo } from 'react';
import useAsync from 'react-use/esm/useAsync';
import { Progress, ErrorPanel } from '@backstage/core-components';
import { useApi } from '@backstage/core-plugin-api';
import { ScorecardInfo } from '../ScorecardsInfo/ScorecardInfo.esm.js';
import { techInsightsApiRef } from '@backstage-community/plugin-tech-insights-react';
import { useEntity } from '@backstage/plugin-catalog-react';
import { getCompoundEntityRef } from '@backstage/catalog-model';

const ScorecardsCard = (props) => {
  const {
    title,
    description,
    checksId,
    filter,
    onlyFailed,
    expanded = true
  } = props;
  const api = useApi(techInsightsApiRef);
  const { entity } = useEntity();
  const { value, loading, error } = useAsync(
    async () => await api.runChecks(getCompoundEntityRef(entity), checksId),
    [api, entity, JSON.stringify(checksId)]
  );
  const filteredValues = !filter || !value ? value : value.filter((val) => filter(val.check));
  const checkResultRenderers = useMemo(() => {
    if (!onlyFailed || !filteredValues) return {};
    const types = [...new Set(filteredValues.map(({ check }) => check.type))];
    const renderers = api.getCheckResultRenderers(types);
    return Object.fromEntries(
      renderers.map((renderer) => [renderer.type, renderer])
    );
  }, [api, filteredValues, onlyFailed]);
  if (loading) {
    return /* @__PURE__ */ jsx(Progress, {});
  } else if (error) {
    return /* @__PURE__ */ jsx(ErrorPanel, { error });
  }
  const filteredValue = !onlyFailed ? filteredValues || [] : (filteredValues || []).filter(
    (val) => checkResultRenderers[val.check.type]?.isFailed?.(val)
  );
  return /* @__PURE__ */ jsx(
    ScorecardInfo,
    {
      title,
      description,
      entity,
      checkResults: filteredValue,
      noWarning: onlyFailed,
      expanded
    }
  );
};

export { ScorecardsCard };
//# sourceMappingURL=ScorecardsCard.esm.js.map
