import { jsx } from 'react/jsx-runtime';
import useAsync from 'react-use/esm/useAsync';
import { Progress, Page, Content } from '@backstage/core-components';
import { useApi } from '@backstage/core-plugin-api';
import { ScorecardInfo } from '../ScorecardsInfo/ScorecardInfo.esm.js';
import Alert from '@material-ui/lab/Alert';
import { techInsightsApiRef } from '@backstage-community/plugin-tech-insights-react';
import { makeStyles } from '@material-ui/core/styles';
import { useEntity } from '@backstage/plugin-catalog-react';
import { getCompoundEntityRef } from '@backstage/catalog-model';

const useStyles = makeStyles(() => ({
  contentScorecards: {
    paddingLeft: 0,
    paddingRight: 0
  }
}));
const ScorecardsContent = (props) => {
  const { title, description, checksId, filter } = props;
  const classes = useStyles();
  const api = useApi(techInsightsApiRef);
  const { entity } = useEntity();
  const { namespace, kind, name } = getCompoundEntityRef(entity);
  const { value, loading, error } = useAsync(
    async () => await api.runChecks({ namespace, kind, name }, checksId)
  );
  const filteredValues = !filter || !value ? value : value.filter((val) => filter(val.check));
  if (loading) {
    return /* @__PURE__ */ jsx(Progress, {});
  } else if (error) {
    return /* @__PURE__ */ jsx(Alert, { severity: "error", children: error.message });
  }
  return /* @__PURE__ */ jsx(Page, { themeId: "home", children: /* @__PURE__ */ jsx(Content, { className: classes.contentScorecards, children: /* @__PURE__ */ jsx(
    ScorecardInfo,
    {
      title,
      description,
      entity,
      checkResults: filteredValues || []
    }
  ) }) });
};

export { ScorecardsContent };
//# sourceMappingURL=ScorecardContent.esm.js.map
