import { jsx, jsxs } from 'react/jsx-runtime';
import { useApi } from '@backstage/core-plugin-api';
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import ListItemSecondaryAction from '@material-ui/core/ListItemSecondaryAction';
import ListItemText from '@material-ui/core/ListItemText';
import { makeStyles } from '@material-ui/core/styles';
import { MarkdownContent } from '@backstage/core-components';
import { techInsightsApiRef, ResultCheckIcon } from '@backstage-community/plugin-tech-insights-react';

const useStyles = makeStyles((theme) => ({
  listItemText: {
    paddingRight: theme.spacing(0.5)
  }
}));
const ScorecardsList = (props) => {
  const { checkResults, entity } = props;
  const classes = useStyles();
  const api = useApi(techInsightsApiRef);
  const types = [...new Set(checkResults.map(({ check }) => check.type))];
  const checkResultRenderers = api.getCheckResultRenderers(types);
  return /* @__PURE__ */ jsx(List, { children: checkResults.map((result, index) => {
    const checkResultRenderer = checkResultRenderers.find(
      (renderer) => renderer.type === result.check.type
    );
    const description = checkResultRenderer?.description;
    return /* @__PURE__ */ jsxs(ListItem, { children: [
      /* @__PURE__ */ jsx(
        ListItemText,
        {
          primary: result.check.name,
          secondary: description ? description(result) : /* @__PURE__ */ jsx(MarkdownContent, { content: result.check.description }),
          className: classes.listItemText
        },
        index
      ),
      /* @__PURE__ */ jsx(
        ResultCheckIcon,
        {
          result,
          entity,
          component: ListItemSecondaryAction,
          checkResultRenderer
        }
      )
    ] }, result.check.id);
  }) });
};

export { ScorecardsList };
//# sourceMappingURL=ScorecardsList.esm.js.map
